#delimit;
set more 1;
log using /volumes/ddisk/immigration/programs/chapter_4/aggregate/count_smsa_mf_iv.log, replace;


*THIS PROGRAM GENERATES THE PREDICTED COUNTS BASED ON 1980 ETHNIC-GEOGRAPHY DISTRIBUTION;


*STEP 1: GET IMMIGRANT SHARES BY SMSA IN BASELINE 1980 PERIOD;
*USES BPL, EDCODE & EXPCODE TO DEFINE GROUPS;


use /volumes/ddisk/ipums5/ipums80.dta, clear;

*keep if sex==1;
drop if gq==0 | gq==3 | gq==4; 
drop if age<18 | age>64;
*drop if school==2;

generate smsa=int(metaread/10);
drop if smsa==0;
summ smsa;

generate byte imm=(citizen==2 | citizen==3);

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64)
	+ 3*(educd>=65 & educd<=90) + 4*(educd==100 | educd==101) + 5*(educd>=110);

generate exper=age-17 if edcode==1;
replace exper=age-19 if edcode==2;
replace exper=age-21 if edcode==3;
replace exper=age-23 if edcode==4;
replace exper=age-24 if edcode==5;
keep if exper>=1 & exper<=40;

generate expcode=1*(exper>=1 & exper<=5) + 2*(exper>=6 & exper<=10)
		+3*(exper>=11 & exper<=15) + 4*(exper>=16 & exper<=20)
		+5*(exper>=21 & exper<=25) + 6*(exper>=26 & exper<=30)
		+7*(exper>=31 & exper<=35) + 8*(exper>=36 & exper<=40);

generate weeks=wkswork1;
generate hours=uhrswork;

generate weight=weeks*hours/2000;

rename statefip state;
generate pimmig=imm;


*FIX COUNTRY CODES;
replace bpl=410 if bpl>=410 & bpl<=414;



sort bpl;
merge bpl using /volumes/ddisk/immigration/impact/census5/consistent_bpl.dta;
drop _merge;
replace bpl=999 if consistent==. & imm==1;
replace bpl=0 if imm==0;
drop consistent;

keep if imm==1;

summ imm [fw=perwt];

collapse (sum) pimmig [fw=perwt], by(smsa bpl edcode expcode);

egen totimmig=sum(pimmig), by(bpl edcode expcode);

generate share=pimmig/totimmig;

keep smsa bpl edcode expcode share;
sort smsa bpl edcode expcode;

fillin smsa bpl edcode expcode;
drop _fillin;
replace share=0 if share==.;

save /volumes/ddisk/data/junkshare.dta, replace;




*NOW TAKE WEIGHTED AVERAGE USING WEIGHTS FROM 1980





********************************;
*STEP 2, GET ACTUAL & PREDICTED COUNTS FOR EACH CELL;
*START WITH 1980;




*CALCULATES FTE'S, COUNTS OF WORKERS, AND POPULATION COUNTS, USING SMSA CELLS;
*SMSA DATA FOR 1970 IS NOT COMPLETE;





use /volumes/ddisk/ipums5/ipums80.dta, clear;

*keep if sex==1;
drop if gq==0 | gq==3 | gq==4; 
drop if age<18 | age>64;
*drop if school==2;

generate smsa=int(metaread/10);
drop if smsa==0;
summ smsa;

generate byte imm=(citizen==2 | citizen==3);

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64)
	+ 3*(educd>=65 & educd<=90) + 4*(educd==100 | educd==101) + 5*(educd>=110);

generate exper=age-17 if edcode==1;
replace exper=age-19 if edcode==2;
replace exper=age-21 if edcode==3;
replace exper=age-23 if edcode==4;
replace exper=age-24 if edcode==5;
keep if exper>=1 & exper<=40;

generate expcode=1*(exper>=1 & exper<=5) + 2*(exper>=6 & exper<=10)
		+3*(exper>=11 & exper<=15) + 4*(exper>=16 & exper<=20)
		+5*(exper>=21 & exper<=25) + 6*(exper>=26 & exper<=30)
		+7*(exper>=31 & exper<=35) + 8*(exper>=36 & exper<=40);

generate weeks=wkswork1;
generate hours=uhrswork;

generate weight=weeks*hours/2000;
summ weight;

rename statefip state;
generate pimmig=imm;

replace bpl=0 if imm==0;

*FIX COUNTRY CODES;
replace bpl=410 if bpl>=410 & bpl<=414;


sort bpl;
merge bpl using /volumes/ddisk/immigration/impact/census5/consistent_bpl.dta;
drop _merge;
replace bpl=999 if consistent==. & imm==1;
drop consistent;

keep if imm==1;
summ imm [fw=perwt];

collapse (sum) pimmig [fw=perwt], by(smsa bpl edcode expcode);

*THIS SUMM STATEMENT GIVES THE RIGHT NUMBER OF IMMIGRANTS OVERALL IN THE CENSUS YEAR;
summ pimmig;

sort smsa bpl edcode expcode;
merge smsa bpl edcode expcode using /volumes/ddisk/data/junkshare.dta;
drop _merge;

replace pimmig=0 if pimmig==.;
replace share=0 if share==.;


egen pimmig1=sum(pimmig), by(bpl edcode expcode);
summ pimmig1;
replace pimmig1=share*pimmig1;

collapse (sum) pimmig1, by(smsa edcode expcode);

generate survey=1980;
summ;

sort survey smsa edcode expcode pimmig1;
	
save /volumes/ddisk/data/junk80.dta, replace;




**********************************;
*STEP 3: PREDICT FOR 1990;

use /volumes/ddisk/ipums5/ipums90.dta, clear;

*keep if sex==1;
drop if gq==0 | gq==3 | gq==4; 
drop if age<18 | age>64;
*drop if school==2;

generate smsa=int(metaread/10);
drop if smsa==0;
summ smsa;

generate byte imm=(citizen==2 | citizen==3);

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64)
	+ 3*(educd>=65 & educd<=90) + 4*(educd==100 | educd==101) + 5*(educd>=110);

generate exper=age-17 if edcode==1;
replace exper=age-19 if edcode==2;
replace exper=age-21 if edcode==3;
replace exper=age-23 if edcode==4;
replace exper=age-24 if edcode==5;
keep if exper>=1 & exper<=40;

generate expcode=1*(exper>=1 & exper<=5) + 2*(exper>=6 & exper<=10)
		+3*(exper>=11 & exper<=15) + 4*(exper>=16 & exper<=20)
		+5*(exper>=21 & exper<=25) + 6*(exper>=26 & exper<=30)
		+7*(exper>=31 & exper<=35) + 8*(exper>=36 & exper<=40);

generate weeks=wkswork1;
generate hours=uhrswork;

generate weight=weeks*hours/2000;
summ weight;

rename statefip state;
generate pimmig=imm;

replace bpl=0 if imm==0;

*FIX COUNTRY CODES;
replace bpl=410 if bpl>=410 & bpl<=414;


sort bpl;
merge bpl using /volumes/ddisk/immigration/impact/census5/consistent_bpl.dta;
drop _merge;
replace bpl=999 if consistent==. & imm==1;
drop consistent;


keep if imm==1;
summ imm [fw=perwt];

collapse (sum) pimmig [fw=perwt], by(smsa bpl edcode expcode);

*THIS SUMM STATEMENT GIVES THE RIGHT NUMBER OF IMMIGRANTS OVERALL IN THE CENSUS YEAR;
summ pimmig;

sort smsa bpl edcode expcode;
merge smsa bpl edcode expcode using /volumes/ddisk/data/junkshare.dta;
drop _merge;

replace pimmig=0 if pimmig==.;
replace share=0 if share==.;


egen pimmig1=sum(pimmig), by(bpl edcode expcode);
summ pimmig1;
replace pimmig1=share*pimmig1;

collapse (sum) pimmig1, by(smsa edcode expcode);

generate survey=1990;
summ;

sort survey smsa edcode expcode pimmig1;
	
save /volumes/ddisk/data/junk90.dta, replace;


*********************;
*PREDICT FOR 2000;

use /volumes/ddisk/ipums5/ipums00.dta, clear;

*keep if sex==1;
drop if gq==0 | gq==3 | gq==4; 
drop if age<18 | age>64;
*drop if school==2;

generate smsa=int(metaread/10);
drop if smsa==0;
summ smsa;

generate byte imm=(citizen==2 | citizen==3);

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64)
	+ 3*(educd>=65 & educd<=90) + 4*(educd==100 | educd==101) + 5*(educd>=110);

generate exper=age-17 if edcode==1;
replace exper=age-19 if edcode==2;
replace exper=age-21 if edcode==3;
replace exper=age-23 if edcode==4;
replace exper=age-24 if edcode==5;
keep if exper>=1 & exper<=40;

generate expcode=1*(exper>=1 & exper<=5) + 2*(exper>=6 & exper<=10)
		+3*(exper>=11 & exper<=15) + 4*(exper>=16 & exper<=20)
		+5*(exper>=21 & exper<=25) + 6*(exper>=26 & exper<=30)
		+7*(exper>=31 & exper<=35) + 8*(exper>=36 & exper<=40);

generate weeks=wkswork1;
generate hours=uhrswork;

generate weight=weeks*hours/2000;
summ weight;

rename statefip state;
generate pimmig=imm;

replace bpl=0 if imm==0;

*FIX COUNTRY CODES;
replace bpl=410 if bpl>=410 & bpl<=414;


sort bpl;
merge bpl using /volumes/ddisk/immigration/impact/census5/consistent_bpl.dta;
drop _merge;
replace bpl=999 if consistent==. & imm==1;
drop consistent;


keep if imm==1;
summ imm [fw=perwt];

collapse (sum) pimmig [fw=perwt], by(smsa bpl edcode expcode);

*THIS SUMM STATEMENT GIVES THE RIGHT NUMBER OF IMMIGRANTS OVERALL IN THE CENSUS YEAR;
summ pimmig;

sort smsa bpl edcode expcode;
merge smsa bpl edcode expcode using /volumes/ddisk/data/junkshare.dta;
drop _merge;

replace pimmig=0 if pimmig==.;
replace share=0 if share==.;


egen pimmig1=sum(pimmig), by(bpl edcode expcode);
summ pimmig1;
replace pimmig1=share*pimmig1;

collapse (sum) pimmig1, by(smsa edcode expcode);

generate survey=2000;
summ;

sort survey smsa edcode expcode pimmig1;

save /volumes/ddisk/data/junk00.dta, replace;






*************************;
*STEP 5: PREDICT FOR 2010;

use /volumes/ddisk/ipums5/acs0711.dta, clear;

*keep if sex==1;
drop if gq==0 | gq==3 | gq==4; 
drop if age<18 | age>64;
*drop if school==2;

generate smsa=int(metaread/10);
drop if smsa==0;
summ smsa;

generate byte imm=(citizen==2 | citizen==3);

generate byte edcode=1*(educd<=50) + 2*(educd>=60 & educd<=64)
	+ 3*(educd>=65 & educd<=90) + 4*(educd==100 | educd==101) + 5*(educd>=110);

generate exper=age-17 if edcode==1;
replace exper=age-19 if edcode==2;
replace exper=age-21 if edcode==3;
replace exper=age-23 if edcode==4;
replace exper=age-24 if edcode==5;
keep if exper>=1 & exper<=40;

generate expcode=1*(exper>=1 & exper<=5) + 2*(exper>=6 & exper<=10)
		+3*(exper>=11 & exper<=15) + 4*(exper>=16 & exper<=20)
		+5*(exper>=21 & exper<=25) + 6*(exper>=26 & exper<=30)
		+7*(exper>=31 & exper<=35) + 8*(exper>=36 & exper<=40);

rename statefip state;
generate pimmig=imm;

replace bpl=0 if imm==0;

*FIX COUNTRY CODES;
replace bpl=410 if bpl>=410 & bpl<=414;


sort bpl;
merge bpl using /volumes/ddisk/immigration/impact/census5/consistent_bpl.dta;
drop _merge;
replace bpl=999 if consistent==. & imm==1;
drop consistent;


keep if imm==1;
summ imm [fw=perwt];

collapse (sum) pimmig [fw=perwt], by(smsa bpl edcode expcode);

*THIS SUMM STATEMENT GIVES THE RIGHT NUMBER OF IMMIGRANTS OVERALL IN THE CENSUS YEAR;
summ pimmig;

sort smsa bpl edcode expcode;
merge smsa bpl edcode expcode using /volumes/ddisk/data/junkshare.dta;
drop _merge;

replace pimmig=0 if pimmig==.;
replace share=0 if share==.;


egen pimmig1=sum(pimmig), by(bpl edcode expcode);
summ pimmig1;
replace pimmig1=share*pimmig1;

collapse (sum) pimmig1, by(smsa edcode expcode);

generate survey=2010;
summ;

sort survey smsa edcode expcode pimmig1;

save /volumes/ddisk/data/junk07.dta, replace;

use /volumes/ddisk/data/junk80.dta;
append using /volumes/ddisk/data/junk90.dta;
append using /volumes/ddisk/data/junk00.dta;
append using /volumes/ddisk/data/junk07.dta;

sort survey smsa edcode expcode;

save /volumes/ddisk/immigration/programs/chapter_4/aggregate/count_smsa_mf_iv.dta, replace;

log close;


