#delimit ;
set more 1;
clear matrix;
clear mata;
set matsize 7500;
set maxvar 7500;
log using /volumes/ddisk/immigration/programs/chapter_4/Tables_4_1-2-3a_smsa.log, replace;


*USES ALL AVAILABLE SMSA DATA, BEGINNING IN 1970;
*RESCALES WEIGHTS SO THAT EACH SURVEY COUNTS AS 1;

*ALSO PROVIDES RESULTS ON IV REGRESSIONS WITH LAGGED IMMIGRANT SHARE IN TABLE 4.3;


*SET 1, USES M EARNINGS, AND MF COUNTS;

use /volumes/ddisk/immigration/programs/chapter_4/aggregate/wage_smsa_m.dta, clear;
sort survey smsa edcode expcode;
merge survey smsa edcode expcode using /volumes/ddisk/immigration/programs/chapter_4/aggregate/count_smsa_mf.dta;
drop _merge;

keep if imm==0;
drop imm;
sort survey smsa edcode expcode;

egen tobs=sum(sizew), by(survey);
generate weight=sizew/tobs;
tabulate survey, sum(weight);

tabulate edcode, gen(educ);
tabulate survey, gen(year);
tabulate expcode, gen(xp);
tabulate smsa, gen(reg);

generate ppercent=pimmig/(pimmig+pnative);
generate npercent=nimmig/(nimmig+nnative);
generate percentlf=immiglf/(immiglf+nativelf);
tabulate survey [aw=weight], sum(ppercent);
tabulate survey [aw=weight], sum(npercent);
tabulate survey [aw=weight], sum(percentlf);

generate skill=edcode*10 + expcode;
tab skill, gen(edxp);
generate double newcode1=survey*100 + smsa;
generate double newcode2=survey*100 + skill;
generate double newcode3=smsa*100 + skill;

generate code1=survey*10 + edcode;
generate code2=survey*100 + expcode;
generate code3=expcode*10 + edcode;
tabulate code1, gen(inter);
tabulate code2, gen(intra);
tabulate code3, gen(extra);

quietly tabulate newcode1, gen(c1c);
quietly tabulate newcode2, gen(c2c);
*quietly tabulate newcode3, gen(c3c);


*CROSS SECTION SPATIAL CORRELATIONS;
sort survey;
by survey: reg lweekly percentlf edxp* reg* [aw=weight], cluster(newcode1);


*LONGITUDINAL REGRESSION USING 1980-2010 DATA;

areg lweekly percentlf c1c* c2c* if survey>=1980 [aw=weight], 
	absorb(newcode3) cluster(newcode3);
areg lweekly percentlf c1c* c2c* if survey>=1990 [aw=weight], 
	absorb(newcode3) cluster(newcode3);


keep if survey>=1970;


generate good=.;
replace good=1 if survey==1970;
egen p70=mean(good*percentlf), by(smsa edcode expcode);
replace good=.;
replace good=1 if survey==1980;
egen p80=mean(good*percentlf), by(smsa edcode expcode);
replace good=.;
replace good=1 if survey==1990;
egen p90=mean(good*percentlf), by(smsa edcode expcode);
replace good=.;
replace good=1 if survey==2000;
egen p00=mean(good*percentlf), by(smsa edcode expcode);


generate percent0=p70 if survey==1980;
replace percent0=p80 if survey==1990;
replace percent0=p90 if survey==2000;
replace percent0=p00 if survey==2010;


xtivreg2 lweekly c1c* c2c* (percentlf=percent0) [aw=weight]
	if survey>=1990 & survey<=2010,
	fe i(newcode3) cluster(newcode3) first;
xtivreg2 lweekly c1c* c2c* (percentlf=percent0) [aw=weight]
	if survey>=1990 & survey<=2000,
	fe i(newcode3) cluster(newcode3) first;
xtivreg2 lweekly c1c* c2c* (percentlf=percent0) [aw=weight]
	if survey>=2000 & survey<=2010,
	fe i(newcode3) cluster(newcode3) first;









*SET 2, USES MF EARNINGS, AND MF COUNTS;

use /volumes/ddisk/immigration/programs/chapter_4/aggregate/wage_smsa_mf.dta, clear;
sort survey smsa edcode expcode;
merge survey smsa edcode expcode using /volumes/ddisk/immigration/programs/chapter_4/aggregate/count_smsa_mf.dta;
drop _merge;

keep if imm==0;
drop imm;
sort survey smsa edcode expcode;

egen tobs=sum(sizew), by(survey);
generate weight=sizew/tobs;
tabulate survey, sum(weight);

tabulate edcode, gen(educ);
tabulate survey, gen(year);
tabulate expcode, gen(xp);
tabulate smsa, gen(reg);

generate ppercent=pimmig/(pimmig+pnative);
generate npercent=nimmig/(nimmig+nnative);
generate percentlf=immiglf/(immiglf+nativelf);
tabulate survey [aw=weight], sum(ppercent);
tabulate survey [aw=weight], sum(npercent);
tabulate survey [aw=weight], sum(percentlf);

generate skill=edcode*10 + expcode;
tab skill, gen(edxp);
generate double newcode1=survey*100 + smsa;
generate double newcode2=survey*100 + skill;
generate double newcode3=smsa*100 + skill;

generate code1=survey*10 + edcode;
generate code2=survey*100 + expcode;
generate code3=expcode*10 + edcode;
tabulate code1, gen(inter);
tabulate code2, gen(intra);
tabulate code3, gen(extra);

quietly tabulate newcode1, gen(c1c);
quietly tabulate newcode2, gen(c2c);
*quietly tabulate newcode3, gen(c3c);


*CROSS SECTION SPATIAL CORRELATIONS;
sort survey;
by survey: reg lweekly percentlf edxp* reg* [aw=weight], cluster(newcode1);


*LONGITUDINAL REGRESSION USING 1980-2010 DATA;

areg lweekly percentlf c1c* c2c* if survey>=1980 [aw=weight], 
	absorb(newcode3) cluster(newcode3);
areg lweekly percentlf c1c* c2c* if survey>=1990 [aw=weight], 
	absorb(newcode3) cluster(newcode3);


keep if survey>=1970;


generate good=.;
replace good=1 if survey==1970;
egen p70=mean(good*percentlf), by(smsa edcode expcode);
replace good=.;
replace good=1 if survey==1980;
egen p80=mean(good*percentlf), by(smsa edcode expcode);
replace good=.;
replace good=1 if survey==1990;
egen p90=mean(good*percentlf), by(smsa edcode expcode);
replace good=.;
replace good=1 if survey==2000;
egen p00=mean(good*percentlf), by(smsa edcode expcode);


generate percent0=p70 if survey==1980;
replace percent0=p80 if survey==1990;
replace percent0=p90 if survey==2000;
replace percent0=p00 if survey==2010;


xtivreg2 lweekly c1c* c2c* (percentlf=percent0) [aw=weight]
	if survey>=1990 & survey<=2010,
	fe i(newcode3) cluster(newcode3) first;


log close;